# RPU

**R**andom **P**ython **U**tilities is a library that contains stuff that (I know I) and you probably are tired of adding to all of your projects. But with rpu you can just add it as a requirement and no more copy pasting! Main benefit of using rpu over copy pasting is that if there is a bug found with the code, instead of having to fix it in all of your projects it can just be fixed in the library and then its fixed for everyone.

Our docs are located at rpu.cibere.dev. View the <a href="https://rpu.cibere.dev/stable/index.html">stable docs here</a>, and <a href="https://rpu.cibere.dev/latest/index.html">latest docs here</a>

## Key Features

### Grammar

- Plural
- possessive
- ordinal

### Numbers

- word_to_int
- int_to_word

### Iterables

- chunk
- get

### async

- run_in_executor
- execute_func

### CLI

- command infrustructure

### Consts

- MISSING

### Dicts

- flip_dict

### HTTP

- QueryParams
- Headers
- Route

### Objects

- Object

### Chars

- Invisible Character(s)
- Arrows (left, right, up, down)
- Bullet Point

# Credits

You can view the credits <a href="https://github.com/cibere/rpu/blob/main/extras/credits.md">here</a>
